Welcome to ClientVPS Mirrors

Help for package platowork
Title: Data from a Test of the PlatoWork tDCS Headset
Version: 0.0.1
Description: Data and analysis from an experiment with improving touch typing speed, using the tDCS PlatoWork headset produced by PlatoScience.
URL: https://github.com/lassehjorthmadsen/platowork
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.1.1
Depends: R (≥ 2.10)
Suggests: dplyr, ggplot2, knitr, purrr, rmarkdown, testthat
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2021-05-03 14:02:35 UTC; Lasse
Author: Lasse Hjorth Madsen [aut, cre]
Maintainer: Lasse Hjorth Madsen <lassehjorthmadsen@gmail.com>
Repository: CRAN
Date/Publication: 2021-05-04 06:50:05 UTC

Results of touch type experiment with two subject using the PlatoWork tDCS headset for possible improvement of learning speed.

Description

Results of touch type experiment with two subject using the PlatoWork tDCS headset for possible improvement of learning speed.

Usage

plato

Format

A data frame with 225 rows and 6 variables:

date

time of test

subject

name of person doing the typing test

wpm

words per minute in typing test

error

error rate in typing test

stimulus

type of stimulus

session

session id, unique for each subject

...

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.